@@ -10,17 +10,20 @@ class WialonRoute(WialonObject):
         Creates the route in Wialon and sets its id.
 
         :param creator_id: A Wialon user id to set as the route's creator.
-        :type creator_id: :py:obj:`int` | :py:obj:`str`
+        :type creator_id: int | str
         :param name: Wialon route name.
-        :type name: :py:obj:`str`
+        :type name: str
         :raises ValueError: If ``creator_id`` wasn't a digit.
         :raises WialonAPIError: If something went wrong calling the Wialon API.
         :returns: A Wialon object dictionary.
-        :rtype: :py:obj:`dict`[:py:obj:`str`, :py:obj:`str`]
+        :rtype: dict[str, str]
 
         """
         if isinstance(creator_id, str) and not creator_id.isdigit():
-            raise ValueError(f"'creator_id' must be a digit, got '{creator_id}'.")
+            raise ValueError(
+                f"'creator_id' must be a digit, got '{creator_id}'."
+            )
+
         response = self.session.wialon_api.core_create_route(
             **{
                 "creatorId": creator_id,
